package cn.com.ty.lift.business.emergency.controller;


import cn.com.ty.lift.business.common.CountPage;
import cn.com.ty.lift.business.common.RestResult;
import cn.com.ty.lift.business.emergency.dto.RepairRequest;
import cn.com.ty.lift.business.emergency.dto.RepairResponse;
import cn.com.ty.lift.business.emergency.entity.EmergencyRepair;
import cn.com.ty.lift.business.emergency.service.impl.EmergencyRepairServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 临修记录 前端控制器
 * </p>
 *
 * @author wcz
 * @since 2019-12-04
 */
@RestController
@AllArgsConstructor
@RequestMapping("/emergency/emergency-repair")
public class EmergencyRepairController {

    private EmergencyRepairServiceImpl emergencyRepairService;

    /**
     * @description 根据id查找
     * @date 2019/12/6 10:14
     * @param
     * @return
     */
    @PostMapping("findOne")
    public RestResponse findOne(@RequestBody RepairRequest request){
        long id = request.getId();
        if(id == 0){
            return RestResult.errParam();
        }
        RepairResponse result = emergencyRepairService.selectByIdWithInfo(request);
        if(null == result){
            return RestResult.fail();
        }
        return RestResult.okData(result);
    }

    /**
     * @description 新增急修单
     * @date 2019/12/9 9:43
     * @param
     * @return
     */
    @PostMapping("add")
    public RestResponse add(@RequestBody EmergencyRepair entity){

        if(null == entity){
            return RestResult.errParam();
        }
        boolean result = emergencyRepairService.save(entity);
        if(result){
            return RestResult.okData(result);
        }
        return RestResult.fail();
    }

    /**
     * @description 分页查询急修中的 status <> 4
     * @date 2019/12/9 9:39
     * @param 
     * @return 
     */
    @PostMapping("list")
    public RestResponse list(@RequestBody RepairRequest request){
        IPage<RepairResponse> pages = emergencyRepairService.listByRepairing(request);
        if(null == pages){
            return RestResult.fail();
        }
        long count = pages.getTotal();
        CountPage<RepairResponse> countPage = new CountPage<>(count,pages);
        return RestResult.okData(countPage);
    }

    /**
     * @description 根据条件分页查询
     * @date 2019/12/9 9:39
     * @param 
     * @return 
     */
    @PostMapping("page")
    public RestResponse page(@RequestBody RepairRequest request){
        IPage<RepairResponse> pages = emergencyRepairService.listByCondition(request);
        if(null == pages){
            return RestResult.fail();
        }
        long count = emergencyRepairService.countByCondition(request);
        CountPage<RepairResponse> countPage = new CountPage<>(count,pages);
        return RestResult.okData(countPage);
    }

    /**
     * @description 急修单转派
     * @date 2019/12/11 9:25
     * @param
     * @return
     */
    @PostMapping("transfer")
    public RestResponse transfer(@RequestBody RepairRequest request){
        Long id = request.getId();
        Long workerId = request.getWorkerId();
        if(null == id || null == workerId){
            return RestResult.errParam();
        }
        EmergencyRepair entity = emergencyRepairService.getById(id);
        if(null == entity){
            return RestResult.errParam();
        }
        //本急修单的负责维保工
        entity.setWorkerId1(workerId);
        boolean result = emergencyRepairService.saveOrUpdate(entity);
        if(result){
            return RestResult.okData(result);
        }
        return RestResult.fail();
    }

    /**
     * @description 关闭急修单
     * @date 2019/12/11 9:25
     * @param
     * @return
     */
    @PostMapping("close")
    public RestResponse close(@RequestBody RepairRequest request){
        Long id = request.getId();
        if(null == id){
            return RestResult.errParam();
        }
        EmergencyRepair entity = emergencyRepairService.getById(id);
        if(null == entity){
            return RestResult.errParam();
        }
        //状态（0 待完成；1 已签到，待修理；2 已修理；3 待评价；4 完成 5 暂停中 6 关闭）
        entity.setStatus(6);
        boolean result = emergencyRepairService.saveOrUpdate(entity);
        if(result){
            return RestResult.okData(result);
        }
        return RestResult.fail();
    }
}
