package cn.com.ty.lift.enterprise.custom.service.impl;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.enterprise.custom.dao.entity.PropertyCompany;
import cn.com.ty.lift.enterprise.custom.dao.entity.PropertyContact;
import cn.com.ty.lift.enterprise.custom.dao.entity.model.PropertyCompanyAndPropertyContactReq;
import cn.com.ty.lift.enterprise.custom.dao.entity.model.PropertyCompanyReq;
import cn.com.ty.lift.enterprise.custom.dao.mapper.PropertyCompanyMapper;
import cn.com.ty.lift.enterprise.custom.service.PropertyCompanyService;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * (甲方公司)客户表 服务实现类
 * </p>
 *
 * @author wang-hai-cheng
 * @since 2019-11-11
 */
@Service
@Transactional
@AllArgsConstructor
public class PropertyCompanyServiceImpl extends ServiceImpl<PropertyCompanyMapper, PropertyCompany> implements PropertyCompanyService {
    private final PropertyContactServiceImpl propertyContactService;

    public RestResponse delete(Long id) {
        PropertyCompany byId = this.getById(id);
        if (byId.getStatus() == 2) {
            return RestResponse.ok(null, "0", "有正在服务的关联项目，无法删除");
        } else if (this.getBaseMapper().selectProjectCount() != null && this.getBaseMapper().selectProjectCount().get("count") > 0) {
            return RestResponse.ok(null, "0", "有正在服务的关联项目，无法删除");
        } else {
            byId.setStatus(0);
            if (this.updateById(byId)) {
                return RestResponse.ok(null, "1", "删除成功");
            }
            return RestResponse.ok(null, "0", "删除失败");
        }
    }

    public RestResponse propertyCompanies(PropertyCompanyReq propertyCompany) {
        Page<PropertyCompany> page = new Page<>(propertyCompany.getPageNum(), propertyCompany.getPageSize());
        //根据请求参数查询客户列表
        IPage<PropertyCompany> records = this
                .page(page, new QueryWrapper<PropertyCompany>()
                        .select("id", "mt_company_id", "name", "mailing_address", "telephone", "status")
                        .eq("mt_company_id", propertyCompany.getMtCompanyId())
                        .ne("status", 0)
                        .like(propertyCompany.getName() != null, "name", propertyCompany.getName())
                        .or()
                        .like(propertyCompany.getAddress() != null, "address", propertyCompany.getAddress())
                        .or()
                        .like(propertyCompany.getTelephone() != null, "telephone", propertyCompany.getTelephone())
                        .or()
                        .like(propertyCompany.getMailingAddress() != null, "mailing_address", propertyCompany.getMailingAddress()));
        if (records.getRecords().isEmpty()) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "无数据");
        }
        System.out.println(records);
        return RestResponse.ok(records, ApiConstants.RESULT_SUCCESS, "查询成功");
    }

    public RestResponse saveAll(PropertyCompanyAndPropertyContactReq req) {
        long id = IdWorker.getId();
        req.getPropertyCompany().setId(id);
        req.getPropertyContacts().forEach(contact -> {
            contact.setPpCompanyId(id);
        });
        if (this.save(req.getPropertyCompany()) && propertyContactService.saveBatch(req.getPropertyContacts())) {
            return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "新增成功");
        }
        return RestResponse.ok(null, ApiConstants.RESULT_ERROR, "新增失败");
    }

    public RestResponse export() {
        return RestResponse.ok(null, ApiConstants.RESULT_ERROR, "待实现");
    }

    //更新客户公司和客户联系人的status
    @Transactional
    public RestResponse updateStatus(PropertyCompanyReq req) {
        PropertyCompany companyById = this.getById(req.getPropertyCompanyId());
        PropertyContact contactById = propertyContactService.getById(req.getPropertyContactId());
        if (companyById == null | contactById == null) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "客户或联系人不存在");
        }
        companyById.setStatus(2);
        contactById.setStatus(2);
        if (this.updateById(companyById) && propertyContactService.updateById(contactById)) {
            return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "成功");
        }
        return RestResponse.ok(null, ApiConstants.RESULT_ERROR, "失败");
    }
}