package cn.com.ty.lift.enterprise.organization.service;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.enterprise.organization.dao.entity.Project;
import cn.com.ty.lift.enterprise.organization.dao.entity.model.OrganizationReq;
import cn.com.ty.lift.enterprise.organization.service.impl.ProjectServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
@AllArgsConstructor
public class OrganizationService {
    private final ProjectServiceImpl projectService;

    /**
     * @return 省，市，区，项目列表
     * @description 获取省，市，区，项目列表
     * @date 2019/12/17 10:05
     */
    public RestResponse organization(OrganizationReq req) {
        List<HashMap<String, String>> areas;
        List<HashMap<String, String>> areaChild;
        HashMap<String, Object> result;
        if (req.getDistrict() != null) {
            List<HashMap<String, String>> projects = projectService.getBaseMapper().projects(req.getMtCompanyId(), req.getDistrict());
            if (projects.isEmpty()) {
                return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "无数据");
            }
            //如果查询到了项目
            result = new HashMap<>();
            result.put("projectNum", projects.size());
            result.put("projects", projects);
            return RestResponse.ok(result, ApiConstants.RESULT_SUCCESS, "查询成功");
        } else if (req.getCity() != null) {
            areas = projectService.getBaseMapper().districts(req.getMtCompanyId(), req.getCity());
        } else if (req.getProvince() != null) {
            areas = projectService.getBaseMapper().cities(req.getMtCompanyId(), req.getProvince());
        } else {
            areas = projectService.getBaseMapper().provinces(req.getMtCompanyId());
            if (areas.isEmpty()) {
                return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "无数据");
            }
        }
        if (areas.isEmpty()) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "无数据");
        }
        //如果查询到了区域
        result = new HashMap<>();
        result.put("areaNum", areas.size());
        result.put("areas", areas);
        return RestResponse.ok(result, ApiConstants.RESULT_SUCCESS, "查询成功");
    }

    public RestResponse users(Project project) {
        List<HashMap<String, Object>> projectUsers = projectService.getBaseMapper().users(project.getId());
        if (projectUsers.isEmpty()) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "无数据");
        }
//        for (HashMap<String, Object> projectUser : projectUsers) {
//            Object monitor = projectUser.get("monitor");
//            Object role = projectUser.get("role");
//            if (monitor != null && monitor.equals("1")) {
//                projectUser.replace("monitor", "维保班长");
//            }
//            if (role != null) {
//                switch (role.toString()) {
//                    case "13":
//                        projectUser.replace("role", "维保工");
//                        break;
//                    case "14":
//                        projectUser.replace("role", "省级经理");
//                        break;
//                    case "15":
//                        projectUser.replace("role", "市级经理");
//                        break;
//                    case "16":
//                        projectUser.replace("role", "文员");
//                        break;
//                }
//            }
//        }
        return RestResponse.ok(projectUsers, ApiConstants.RESULT_SUCCESS, "查询成功");
    }
}
