package cn.com.ty.lift.enterprise.region.controller;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.enterprise.common.mapper.CommonMapper;
import cn.com.ty.lift.enterprise.region.dao.entity.Region;
import cn.com.ty.lift.enterprise.region.dao.entity.model.RegionReq;
import cn.com.ty.lift.enterprise.region.service.impl.RegionServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.*;

/**
 * <p>
 * 区域表 前端控制器
 * </p>
 *
 * @author wang-hai-cheng
 * @since 2019-12-09
 */
@AllArgsConstructor
@RestController
@RequestMapping("/region")
public class RegionController {
    private final RegionServiceImpl regionService;
    private final CommonMapper mapper;

    @PostMapping("/list")
    public RestResponse list(@RequestBody RegionReq regionReq) {
        return regionService.regions(regionReq);
    }

    @PostMapping("/add")
    public RestResponse add(@RequestBody Region region) {
        if (regionService.save(region)) {
            return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "新增成功");
        }
        return RestResponse.ok(null, ApiConstants.RESULT_ERROR, "新增失败");
    }

    @PostMapping("/delete")
    public RestResponse delete(@RequestBody Region region) {
        return regionService.delete(region);
    }

    @PostMapping("/update")
    public RestResponse update(@RequestBody Region region) {
        if (regionService.updateById(region)) {
            return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "修改成功");
        }
        return RestResponse.ok(null, ApiConstants.RESULT_ERROR, "修改失败");
    }

    @PostMapping
    public RestResponse region(@RequestBody Region region) {
        Region byId = regionService.getById(region.getId());
        if (null == byId) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "未找到");
        }
        return RestResponse.ok(byId, ApiConstants.RESULT_SUCCESS, "查询成功");
    }

    /**
     * @param
     * @return
     * @description 项目模块，查询区域列表
     * @date 2019/12/17 10:35
     */
    @PostMapping("/project/regions")
    public RestResponse regions(@RequestBody Region region) {
        List<Region> regions = regionService.list(new QueryWrapper<Region>()
                .select("id", "area_name")
                .eq("mt_company_id", region.getMtCompanyId()));
        if (regions.isEmpty()) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "无数据");
        }
        return RestResponse.ok(regions, ApiConstants.RESULT_SUCCESS, "成功");
    }

    /**
     * @param
     * @return
     * @description 项目模块，查询区列表
     * @date 2019/12/17 10:34
     */
    @PostMapping("/project/areas")
    public RestResponse areas(@RequestBody Region region) {
        Region byId = regionService.getById(region.getId());
        if (byId == null) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "无此区域");
        }
        String cityCode = byId.getCityCode();
        List<Map<String, Object>> area_code = mapper.list("name,code", "area_code", "where parent=" + cityCode);
        if (area_code.isEmpty()) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "无数据");
        }
        return RestResponse.ok(area_code, ApiConstants.RESULT_SUCCESS, "查询成功");
    }

    /**
     * @param
     * @return
     * @description 区域属于的省市名，省市编码
     * @date 2019/12/19 15:15
     */
    @PostMapping("/project/areaInfo")
    public RestResponse projectAreaInfo(@RequestBody Region region) {
        return regionService.projectRegions(region);
    }

    /**
     * @param
     * @return
     * @description 项目模块，根据regionId查询区域主管，区域文员
     * @date 2019/12/17 10:33
     */
    @PostMapping("/user")
    public RestResponse users(@RequestBody Region region) {
        return regionService.selectRegionUser(region);
    }

}