package cn.com.ty.lift.system.user.service.impl;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.common.utils.ProjectUtils;
import cn.com.ty.lift.system.user.dao.entity.MtCompanyUser;
import cn.com.ty.lift.system.user.dao.entity.UserApplication;
import cn.com.ty.lift.system.user.dao.entity.UserRole;
import cn.com.ty.lift.system.user.dao.entity.model.UserApplyRequest;
import cn.com.ty.lift.system.user.dao.entity.model.UserApplyResponse;
import cn.com.ty.lift.system.user.dao.entity.model.UserResponse;
import cn.com.ty.lift.system.user.dao.mapper.UserApplicationMapper;
import cn.com.ty.lift.system.user.service.IUserApplicationService;
import cn.com.ty.lift.system.user.service.IUserRoleService;
import cn.com.ty.lift.system.user.service.IUserService;
import cn.com.ty.lift.system.utils.CommonUtil;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 用户申请表 服务实现类
 * </p>
 *
 * @author huangyuan
 * @since 2019-12-13
 */
@Service
public class UserApplicationService extends ServiceImpl<UserApplicationMapper, UserApplication> implements IUserApplicationService {

    @Autowired
    private MtCompanyUserService mtCompanyUserService;

    @Autowired
    private IUserRoleService userRoleService;

    @Autowired
    private IUserService userService;

    @Override
    public RestResponse applyTeam(UserApplyRequest userApplyRequest) {
        //获取用户原有的申请信息
        UserApplication userApplication = this.getOne(new QueryWrapper<UserApplication>()
                .eq("company_id", userApplyRequest.getCompanyId())
                .eq("user_id", userApplyRequest.getUserId())
        );
        if (userApplication != null) {
            //判断用户是否可以申请认证
            LocalDateTime oldApplyTime = userApplication.getApplyDate();
            //当前申请时间
            LocalDateTime nowApplyTime = LocalDateTime.now();
            //差值判断
            if (CommonUtil.durationJudge(oldApplyTime, nowApplyTime, 1L)) {
                return RestResponse.ok(null, ApiConstants.RESULT_ERROR, "一天之内不能重复申请两次");
            }
        }
        if (userApplication == null) {
            userApplication = new UserApplication();
            userApplication.setMtCompanyId(userApplyRequest.getCompanyId());
            userApplication.setUserId(userApplyRequest.getUserId());
            //设置申请类型为团队
            userApplication.setType(ApiConstants.ApplicationConstants.APPLY_TYPE_TEAM);
        }
        //审核状态变为待审核
        userApplication.setStatus(ApiConstants.ApplicationConstants.COMPANY_USER_WAIT);
        return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "申请成功");
    }

    @Override
    @Transactional
    public RestResponse teamPass(UserApplyRequest userApplyRequest) {
        //操作者id
        Long operatorId = userApplyRequest.getUserId();
        //加入团队审核通过
        UserApplication userApplication = this.getById(userApplyRequest.getId());
        //1.设置申请信息
        userApplication.setStatus(ApiConstants.ApplicationConstants.COMPANY_USER_PASS);
        userApplication.setDealDate(LocalDateTime.now());
        userApplication.setDealUserId(operatorId);
        //2.更新公司用户信息
        Long companyId = userApplication.getMtCompanyId();
        Long userId = userApplication.getUserId();
        //3.给用户分配角色
        UserRole userRole = new UserRole();
        userRole.setCompanyId(companyId);
        userRole.setUserId(userId);
        userRole.setRoleId(userApplyRequest.getRoleId());
        userRoleService.save(userRole);
        //获取公司用户信息
        MtCompanyUser mtCompanyUser = mtCompanyUserService.getOne(new QueryWrapper<MtCompanyUser>()
                .eq("mt_company_id", companyId)
                .eq("user_id", userId)
        );
        //如果公司用户信息不存在，新建信息
        if (mtCompanyUser == null) {
            mtCompanyUser = new MtCompanyUser();
            mtCompanyUser.setMtCompanyId(companyId);
            mtCompanyUser.setUserId(userId);
            mtCompanyUser.setCreateUserId(userId);
            mtCompanyUser.setCreateTime(new Date());
        }
        mtCompanyUser.setUpdateTime(new Date());
        mtCompanyUser.setUpdateUserId(userId);
        //设置用户状态在团队中
        mtCompanyUser.setStatus(ApiConstants.ApplicationConstants.COMPANY_USER_PASS);

        this.updateById(userApplication);
        mtCompanyUserService.saveOrUpdate(mtCompanyUser);
        return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "操作成功");
    }

    @Override
    public RestResponse teamFail(UserApplyRequest userApplyRequest) {
        UserApplication userApplication = this.getById(userApplyRequest.getId());
        //设置申请状态为审核不通过
        userApplication.setStatus(ApiConstants.ApplicationConstants.COMPANY_USER_FAIL);
        this.updateById(userApplication);
        return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "操作成功");
    }

    @Override
    public RestResponse applyList(UserApplyRequest userApplyRequest) {
        List<UserApplyResponse> userApplyResponseList = new ArrayList<>();
        IPage userApplicationPage = new Page(userApplyRequest.getPageNum(), userApplyRequest.getPageSize());
        userApplicationPage = this.page(userApplicationPage, new QueryWrapper<UserApplication>()
                .eq("mt_company_id", userApplyRequest.getCompanyId())
                .eq("status", userApplyRequest.getStatus())
        );
        List<UserApplication> userApplicationList = userApplicationPage.getRecords();
        if (userApplicationList != null && userApplicationList.size() > 0) {
            //获取用id集合
            List<Long> userIdList = ProjectUtils.getAttrList(userApplicationList, "userId", null);
            //用户id对应的用户基本信息
            Map<Long, UserResponse> userIdToUserResponse = userService.getUserResponseByUserIdList(userIdList);
            for (UserApplication userApplication : userApplicationList) {
                UserApplyResponse userApplyResponse = new UserApplyResponse();
                UserResponse userResponse = userIdToUserResponse.get(userApplication.getUserId());
                //设置申请人用户信息
                if (userResponse != null) {
                    userApplyResponse.setUserName(userResponse.getName());
                    userApplyResponse.setUserMobile(userResponse.getMobile());
                    userApplyResponse.setUserType(userResponse.getType());
                }
                //设置申请基础信息
                userApplyResponse.setApplyDate(userApplication.getApplyDate());
                userApplyResponse.setDealDate(userApplication.getDealDate());
                userApplyResponse.setId(userApplication.getId());
                userApplyResponse.setUserId(userApplication.getUserId());

                userApplyResponseList.add(userApplyResponse);
            }
        }
        userApplicationPage.setRecords(userApplyResponseList);
        return RestResponse.ok(userApplicationPage, ApiConstants.RESULT_SUCCESS, "获取申请信息成功");
    }
}
